use web_time::{SystemTime, UNIX_EPOCH};

use crate::StateTransition;
use crate::context::Context;
use crate::model::ClientMessage;
use crate::model::buzz_in::BuzzIn;
use crate::screen::Screen;
use macroquad::prelude::*;

pub struct PlayerScreen {
    token: String,
    username: String,
    score: i32,
    button_pressed: bool,
}

impl PlayerScreen {
    pub fn new(token: &str, username: &str) -> Self {
        Self {
            token: token.to_string(),
            username: username.to_string(),
            score: 0,
            button_pressed: false,
        }
    }
}

impl Screen for PlayerScreen {
    fn handle_frame(&mut self, ctx: &mut Context) -> Option<StateTransition> {
        clear_background(BEIGE);

        let button_color = if self.button_pressed {
            Color::from_hex(0xaa0000)
        } else {
            RED
        };

        let button_size = (screen_width() * 0.33).min(screen_height() * 0.20);
        draw_circle(
            screen_width() * 0.5,
            screen_height() * 0.5,
            button_size * 1.1,
            DARKBROWN,
        );
        draw_circle(
            screen_width() * 0.5,
            screen_height() * 0.5,
            button_size,
            button_color,
        );

        if is_mouse_button_pressed(MouseButton::Left) {
            let loc = Vec2::from(mouse_position());
            let normalize = loc - Vec2::new(screen_width() * 0.5, screen_height() * 0.5);

            if normalize.length() < button_size {
                let timestamp = SystemTime::now();
                let unix_timestamp = timestamp.duration_since(UNIX_EPOCH).expect("Time invalid");

                let time = unix_timestamp.as_secs_f64();

                info!("Button pressed @ {}", time);
                self.button_pressed = true;
                let buzz_in = BuzzIn { time };

                ctx.send_msg(&ClientMessage::BuzzIn(buzz_in));
            }
        }

        None
    }
}
